==> oscars-2.0.2.tar.gz: oscars-2.0.2/include/TSpectrumContainer.h <==
#ifndef GUARD_TSpectrumContainer_h
#define GUARD_TSpectrumContainer_h
////////////////////////////////////////////////////////////////////
//
// Dean Andrew Hidas <dhidas@bnl.gov>
//
// Created on: Thu May 19 16:05:08 EDT 2016
//
////////////////////////////////////////////////////////////////////

#include <vector>
#include <string>

class TSpectrumContainer
{
  public:
    TSpectrumContainer ();
    TSpectrumContainer (std::vector<double> const&);
    TSpectrumContainer (size_t const, double const, double const);
    ~TSpectrumContainer ();

    void Init (size_t const, double const, double const);
    void Init (std::vector<double> const&);

    void   SetFlux     (size_t const, double const);
    void   SetPoint    (size_t const, double const, double const);
    size_t AddPoint    (double const, double const Flux = 0);
    void   AddToFlux   (size_t const, double const);

    void SetNotConverged (size_t const);
    bool AllConverged () const;

    void   Scale       (double const);
    double GetFlux     (size_t const) const;
    double GetEnergy   (size_t const) const;
    double GetAngularFrequency (size_t const) const;
    size_t GetNPoints () const;

    void WriteToFileText (std::string const, std::string const Header = "") const;
    void WriteToFileBinary (std::string const, std::string const Header = "") const;

    void Clear ();
    void AverageFromFilesText (std::vector<std::string> const&);
    void AverageFromFilesBinary (std::vector<std::string> const&);

  private:

    std::vector< std::pair<double, double> > fSpectrumPoints;
    std::vector<double> fCompensation;
    std::vector<int> fNotConverged;


};








#endif

==> oscars-3.0.0.dev1.tar.gz: oscars-3.0.0.dev1/include/TSpectrumContainer.h <==
#ifndef GUARD_TSpectrumContainer_h
#define GUARD_TSpectrumContainer_h
////////////////////////////////////////////////////////////////////
//
// Dean Andrew Hidas <dhidas@bnl.gov>
//
// Created on: Thu May 19 16:05:08 EDT 2016
//
////////////////////////////////////////////////////////////////////

#include <vector>
#include <string>

class TSpectrumContainer
{
  public:
    TSpectrumContainer ();
    TSpectrumContainer (std::vector<double> const&);
    TSpectrumContainer (size_t const, double const, double const);
    ~TSpectrumContainer ();

    void Init (size_t const, double const, double const);
    void Init (std::vector<double> const&);

    void   SetFlux     (size_t const, double const);
    void   SetPoint    (size_t const, double const, double const);
    size_t AddPoint    (double const, double const Flux = 0);
    void   AddToFlux   (size_t const, double const);

    void SetNotConverged (size_t const);
    bool AllConverged () const;

    void   Scale       (double const);
    double GetFlux     (size_t const) const;
    double GetEnergy   (size_t const) const;
    double GetAngularFrequency (size_t const) const;
    size_t GetNPoints () const;

    void WriteToFileText (std::string const, std::string const Header = "") const;
    void WriteToFileBinary (std::string const, std::string const Header = "") const;

    void Clear ();
    void AverageFromFilesText (std::vector<std::string> const&,
                               std::vector<double> const& Weights = std::vector<double>());
    void AverageFromFilesBinary (std::vector<std::string> const&,
                               std::vector<double> const& Weights = std::vector<double>());
    void AverageFromSpectra (std::vector<TSpectrumContainer> const& Spectra,
                             std::vector<double> const& Weights = std::vector<double>());

  private:

    std::vector< std::pair<double, double> > fSpectrumPoints;
    std::vector<double> fCompensation;
    std::vector<int> fNotConverged;


};








#endif
